@@ -49,6 +49,25 @@ def del_conflict(inst, basedn, log, args):
     conflict.delete()
 
 
+def del_all_conflicts(inst, basedn, log, args):
+    count = 0
+    failed = 0
+    conflicts = ConflictEntries(inst, args.suffix).list()
+    for conflict in conflicts:
+        try:
+            log.info(f"Deleting conflict entry: {conflict.dn}")
+            conflict.delete()
+            count += 1
+        except Exception as e:
+            log.error(f"Failed to delete conflict entry {conflict.dn}: {str(e)}")
+            failed += 1
+
+    if failed > 0:
+        log.warning(f"Deleted {count} conflict entries, {failed} failed.")
+    else:
+        log.info(f"Deleted {count} conflict entries.")
+
+
 def swap_conflict(inst, basedn, log, args):
     conflict = ConflictEntry(inst, args.DN)
     conflict.swap()
@@ -101,6 +120,10 @@ def create_parser(subparsers):
     del_parser.add_argument('DN', help='The DN of the conflict entry')
     del_parser.set_defaults(func=del_conflict)
 
+    del_all_parser = subcommands.add_parser('delete-all', help="Delete all conflict entries", formatter_class=CustomHelpFormatter)
+    del_all_parser.add_argument('suffix', help='Sets the backend name, or suffix, to remove all conflict entries from')
+    del_all_parser.set_defaults(func=del_all_conflicts)
+
     replace_parser = subcommands.add_parser('swap', help="Replace the valid entry with the conflict entry", formatter_class=CustomHelpFormatter)
     replace_parser.add_argument('DN', help='The DN of the conflict entry')
     replace_parser.set_defaults(func=swap_conflict)
